@@ -5,6 +5,7 @@ import (
 	"context"
 	"crypto/rand"
 	"fmt"
+	"strings"
 
 	"github.com/docker/distribution/reference"
 	"github.com/docker/docker/api/types"
@@ -264,13 +265,50 @@ func (b *TaskLauncher) StopTask(
 	log hclog.Logger,
 	ti *TaskInfo,
 ) error {
+	log = log.With("container_id", ti.Id)
+	log.Debug("connecting to Docker")
 	cli, err := wpdockerclient.NewClientWithOpts(client.FromEnv)
 	if err != nil {
 		return status.Errorf(codes.FailedPrecondition, "unable to create Docker client: %s", err)
 	}
 	cli.NegotiateAPIVersion(ctx)
 
-	return cli.ContainerStop(ctx, ti.Id, nil)
+	log.Debug("stopping container")
+	if err := cli.ContainerStop(ctx, ti.Id, nil); err != nil {
+		// We're going to ignore this error other than logging it, just
+		// so we can try to remove it below. We want to do everything we can
+		// to remove this container.
+		log.Warn("error stopping container", "err", err)
+	}
+
+	// If we're debugging, we do NOT remove the container so that
+	// an operator can come in and inspect it.
+	if b.config.DebugContainers {
+		log.Info("not removing container, debug containers is enabled")
+		return nil
+	}
+
+	log.Debug("removing container")
+	if err := cli.ContainerRemove(ctx, ti.Id, types.ContainerRemoveOptions{
+		Force: true,
+	}); err != nil {
+		if strings.Contains(err.Error(), "already in progress") {
+			// "removal of container already in progress" is the error when
+			// the daemon is removing this for some reason (auto remove or
+			// other). This is not an error.
+			err = nil
+		} else if strings.Contains(strings.ToLower(err.Error()), "no such container") {
+			// Container is already removed
+			err = nil
+		}
+
+		if err != nil {
+			log.Warn("error removing container", "err", err)
+			return err
+		}
+	}
+
+	return nil
 }
 
 // StartTask creates a docker container for the task.
@@ -318,6 +356,7 @@ func (b *TaskLauncher) StartTask(
 		"oci-url", tli.OciUrl,
 		"arguments", tli.Arguments,
 		"environment", env,
+		"autoremove", !b.config.DebugContainers,
 	)
 
 	var memory int64
