@@ -62,7 +62,7 @@ func (c *DeploymentListCommand) Run(args []string) int {
 	if err := c.Init(
 		WithArgs(args),
 		WithFlags(c.Flags()),
-		WithMultipleApp(),
+		WithMultiAppTargets(),
 	); err != nil {
 		return 1
 	}
