@@ -33,7 +33,7 @@ func (c *ReleaseCreateCommand) Run(args []string) int {
 	if err := c.Init(
 		WithArgs(args),
 		WithFlags(c.Flags()),
-		WithMultipleApp(),
+		WithMultiAppTargets(),
 	); err != nil {
 		return 1
 	}
