@@ -25,7 +25,7 @@ func (c *UserModifyCommand) Run(args []string) int {
 		WithArgs(args),
 		WithFlags(c.Flags()),
 		WithNoConfig(),
-		WithNoAutoServer(), // local mode has no need for tokens
+		WithNoLocalServer(), // local mode has no need for tokens
 	); err != nil {
 		return 1
 	}
