@@ -7,6 +7,7 @@ import (
 	"github.com/hashicorp/go-hclog"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
+	configpkg "github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/runner"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	"github.com/hashicorp/waypoint/internal/serverclient"
@@ -45,6 +46,9 @@ type Project struct {
 	// May not be present.
 	configPath string
 
+	// The entire waypoint config file
+	waypointHCL *configpkg.Config
+
 	// These are used to manage a local runner and its job processing
 	// in a goroutine.
 	wg           sync.WaitGroup
@@ -277,11 +281,11 @@ func WithUseLocalRunner(useLocalRunner bool) Option {
 	}
 }
 
-// WithConfigPath sets the path to the local directory that contains our config
-// file (waypoint.hcl).
-func WithConfigPath(configPath string) Option {
+// WithConfig sets the config file (waypoint.hcl) and path.
+func WithConfig(waypointHCL *configpkg.Config) Option {
 	return func(c *Project, cfg *config) error {
-		c.configPath = configPath
+		c.waypointHCL = waypointHCL
+		c.configPath = waypointHCL.ConfigPath()
 		return nil
 	}
 }
