@@ -38,8 +38,8 @@ func (c *Project) initServerClient(ctx context.Context, cfg *config) (*grpc.Clie
 
 	// If we're local, then connection is optional.
 	opts := cfg.connectOpts
-	if c.local {
-		log.Trace("WithLocal set, server credentials optional")
+	if !c.noLocalServer {
+		log.Trace("Local server may be created later - server credentials optional")
 		opts = append(opts, serverclient.Optional())
 	}
 
