@@ -1,6 +1,7 @@
 package core
 
 import (
+	"bytes"
 	"context"
 	"encoding/json"
 	"fmt"
@@ -8,6 +9,7 @@ import (
 
 	"github.com/golang/protobuf/proto"
 	"github.com/golang/protobuf/ptypes/any"
+	"github.com/hashicorp/go-argmapper"
 	"github.com/hashicorp/go-hclog"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
@@ -32,15 +34,17 @@ type operation interface {
 	// Do performs the actual operation and returns the result that you
 	// want to return from the operation. This result will be marshaled into
 	// the ValuePtr if it implements ProtoMarshaler.
-	// Do can alter the proto.Message into it's final form, as it's the value
+	// Do can alter the proto.Message into its final form, as it's the value
 	// returned by Init and that will be written back via Upsert after Do
 	// has completed.
 	Do(context.Context, hclog.Logger, *App, proto.Message) (interface{}, error)
 
 	// StatusPtr and ValuePtr return pointers to the fields in the message
-	// for the status and values respectively.
+	// for the status and values respectively. For ValuePtr, it returns both
+	// a pointer to store the raw message as well as a pointer to store the JSON
+	// of the message. The JSON pointer can be nil and it won't be stored.
 	StatusPtr(proto.Message) **pb.Status
-	ValuePtr(proto.Message) **any.Any
+	ValuePtr(proto.Message) (**any.Any, *string)
 
 	// Hooks are the hooks to execute as part of this operation keyed by "when"
 	Hooks(*App) map[string][]*config.Hook
@@ -100,11 +104,15 @@ func (a *App) doOperation(
 
 	// Get where we'll set the value. Similar to statusPtr, we set this
 	// to a local value if we get nil so that we can avoid nil checks.
-	valuePtr := op.ValuePtr(msg)
+	valuePtr, valueJsonPtr := op.ValuePtr(msg)
 	if valuePtr == nil {
 		var value *any.Any
 		valuePtr = &value
 	}
+	if valueJsonPtr == nil {
+		var valueJson string
+		valueJsonPtr = &valueJson
+	}
 
 	var doErr error
 
@@ -126,6 +134,44 @@ func (a *App) doOperation(
 	if doErr == nil {
 		log.Debug("running local operation")
 		result, doErr = op.Do(ctx, log, a, msg)
+
+		// If we got an argmapper error, we transfor it into something a
+		// bit more readable for the average Waypoint user.
+		if err, ok := doErr.(*argmapper.ErrArgumentUnsatisfied); ok && err != nil {
+			// Log the full error
+			log.Warn("argmapper unsatified error received", "error", doErr)
+
+			// Build our list of missing arguments
+			missing := new(bytes.Buffer)
+			for _, v := range err.Args {
+				s := v.String()
+
+				// If this is an any type with a subtype, then we just use
+				// the subtype. The subtype wording confuses people so just
+				// note the direct type.
+				if v.Type == anyType && v.Subtype != "" {
+					s = v.Subtype
+				}
+
+				fmt.Fprintf(missing, "    - %s\n", s)
+			}
+
+			doErr = fmt.Errorf(
+				"There was an error while executing a Waypoint plugin for "+
+					"this operation!\n\n"+
+					"One or more required arguments for the plugin was not satisfied. "+
+					"This is usually due to a missing or incompatible set of plugins. "+
+					"For example, only certain build plugins are only compatible with certain "+
+					"registries, and so on. Please inspect the missing argument, the set of "+
+					"plugins you are using, and the documentation to determine if your "+
+					"plugin combination is valid.\n\n"+
+					"Plugin function: %s\n\n"+
+					"==> Missing arguments:\n\n%s",
+				err.Func.Name(),
+				missing.String(),
+			)
+		}
+
 		if doErr == nil {
 			// Set our labels if we can
 			msgUpdateLabels(a, op.Labels(a), msg, result)
@@ -150,6 +196,17 @@ func (a *App) doOperation(
 					doErr = err
 				}
 			}
+
+			// If we can marshal as JSON, do it
+			*valueJsonPtr = ""
+			if m, ok := result.(json.Marshaler); ok {
+				raw, err := m.MarshalJSON()
+				if err != nil {
+					doErr = err
+				} else {
+					*valueJsonPtr = string(raw)
+				}
+			}
 		}
 	}
 
@@ -290,3 +347,6 @@ func msgField(msg proto.Message, f string) reflect.Value {
 	// Get the Id field
 	return val.FieldByName(f)
 }
+
+// anyType is used to compare types.
+var anyType = reflect.TypeOf((*any.Any)(nil))
