@@ -1,8 +1,7 @@
 package ptypes
 
 import (
-	"github.com/go-ozzo/ozzo-validation/v4"
-
+	validation "github.com/go-ozzo/ozzo-validation/v4"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 )
 
@@ -12,3 +11,10 @@ func ValidateRefWorkspaceRules(v *pb.Ref_Workspace) []*validation.FieldRules {
 		validation.Field(&v.Workspace, validation.Required),
 	}
 }
+
+// ValidateRefOperationRules
+func ValidateRefOperationRules(v *pb.Ref_Operation) []*validation.FieldRules {
+	return []*validation.FieldRules{
+		validation.Field(&v.Target, validation.Required),
+	}
+}
