@@ -288,6 +288,45 @@ func TestServiceAuth(t *testing.T) {
 	})
 }
 
+func TestServiceAuth_TriggerToken(t *testing.T) {
+	// Create our server
+	impl, err := New(WithDB(testDB(t)))
+	require.NoError(t, err)
+	s := impl.(*service)
+	ctx := context.Background()
+
+	// "Log in" a default user
+	ctx = userWithContext(ctx, &pb.User{Id: DefaultUserId})
+
+	t.Run("create and validate new token cannot authenticate grpc endpoint", func(t *testing.T) {
+		require := require.New(t)
+
+		resp, err := s.GenerateLoginToken(ctx, &pb.LoginTokenRequest{
+			Trigger: true,
+		})
+		require.NoError(err)
+		token := resp.Token
+
+		require.True(len(token) > 5)
+		t.Logf("token: %s", token)
+
+		// Test some internal state of the token
+		_, body, err := s.decodeToken(token)
+		require.NoError(err)
+		kind, ok := body.Kind.(*pb.Token_Trigger_)
+		assert.True(t, ok)
+		assert.Equal(t, DefaultUserId, kind.Trigger.FromUserId)
+
+		// Verify authing won't work currently
+		_, err = s.Authenticate(context.Background(), token, "test", nil)
+		require.Error(err)
+		e, _ := status.FromError(err)
+		assert.Equal(t, e.Code(), codes.PermissionDenied)
+	})
+
+	// TODO(briancain): Add tests for HTTP endpoint when implemeneted
+}
+
 func TestServiceBootstrapToken(t *testing.T) {
 	ctx := context.Background()
 	require := require.New(t)
