@@ -4,7 +4,6 @@ import (
 	"context"
 
 	"github.com/golang/protobuf/ptypes/empty"
-
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	serverptypes "github.com/hashicorp/waypoint/internal/server/ptypes"
 )
@@ -17,6 +16,21 @@ func (s *service) UpsertOnDemandRunnerConfig(
 		return nil, err
 	}
 
+	if req.Config.TargetRunner == nil {
+		req.Config.TargetRunner = &pb.Ref_Runner{
+			Target: &pb.Ref_Runner_Any{},
+		}
+	} else {
+		// Validate static runner exists on odr profile creation.
+		if t, ok := req.Config.TargetRunner.Target.(*pb.Ref_Runner_Id); ok {
+			_, err := s.GetRunner(ctx, &pb.GetRunnerRequest{
+				RunnerId: t.Id.Id,
+			})
+			if err != nil {
+				return nil, err
+			}
+		}
+	}
 	result := req.Config
 	if err := s.state.OnDemandRunnerConfigPut(result); err != nil {
 		return nil, err
