@@ -5,25 +5,26 @@ import (
 	"fmt"
 	"reflect"
 	"sort"
+	"strings"
 	"time"
 
 	"github.com/golang/protobuf/proto"
 	"github.com/golang/protobuf/ptypes"
 	"github.com/golang/protobuf/ptypes/timestamp"
 	"github.com/hashicorp/go-memdb"
+	"github.com/mitchellh/copystructure"
 	bolt "go.etcd.io/bbolt"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
+	"github.com/hashicorp/waypoint/internal/pkg/graph"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	"github.com/hashicorp/waypoint/internal/server/logbuffer"
+	"github.com/hashicorp/waypoint/internal/serverstate"
 )
 
 var (
 	jobBucket = []byte("jobs")
-
-	jobWaitingTimeout   = 2 * time.Minute
-	jobHeartbeatTimeout = 2 * time.Minute
 )
 
 const (
@@ -33,6 +34,7 @@ const (
 	jobQueueTimeIndexName   = "queue-time"
 	jobTargetIdIndexName    = "target-id"
 	jobSingletonIdIndexName = "singleton-id"
+	jobDependsOnIndexName   = "depends-on"
 
 	maximumJobsIndexed = 10000
 )
@@ -123,6 +125,16 @@ func jobSchema() *memdb.TableSchema {
 					},
 				},
 			},
+
+			jobDependsOnIndexName: {
+				Name:         jobDependsOnIndexName,
+				AllowMissing: true,
+				Unique:       false,
+				Indexer: &memdb.StringSliceFieldIndex{
+					Field:     "DependsOn",
+					Lowercase: true,
+				},
+			},
 		},
 	}
 }
@@ -133,6 +145,13 @@ type jobIndex struct {
 	// SingletonId matches singleton_id if set on the job.
 	SingletonId string
 
+	// DependsOn is the list of jobs that this job depends on. If these
+	// don't exist, they're assumed to have COMPLETED due to pruning,
+	// since we don't allow job creation unless they existed in the past,
+	// and if they errored then they would've immediately set this job
+	// state to error.
+	DependsOn []string
+
 	// OpType is the operation type for the job.
 	OpType reflect.Type
 
@@ -172,22 +191,6 @@ func jobIsCompleted(state pb.Job_State) bool {
 	}
 }
 
-// Job is the exported structure that is returned for most state APIs
-// and gives callers access to more information than the pure job structure.
-type Job struct {
-	// Full job structure.
-	*pb.Job
-
-	// OutputBuffer is the terminal output for this job. This is a buffer
-	// that may not contain the full amount of output depending on the
-	// time of connection.
-	OutputBuffer *logbuffer.Buffer
-
-	// Blocked is true if this job is blocked on another job for the same
-	// project/app/workspace.
-	Blocked bool
-}
-
 // JobCreate queues the given jobs. If any job fails to queue, no jobs
 // are queued. If partial failures are acceptible, call this multiple times
 // with a single job.
@@ -195,12 +198,49 @@ func (s *State) JobCreate(jobs ...*pb.Job) error {
 	txn := s.inmem.Txn(true)
 	defer txn.Abort()
 
+	// Before we do any job creation, we go through and verify that
+	// any dependencies being created do not result in a cycle. We know
+	// that jobs already created couldn't have depended on these new jobs
+	// because a dependency must exist at time of creation, so we only
+	// need to check our new dependencies for cycles between each other.
+	jobMap := map[string]*pb.Job{}
+	var depGraph graph.Graph
+	for _, job := range jobs {
+		// Add our job
+		jobId := strings.ToLower(job.Id)
+		jobMap[jobId] = job
+		depGraph.Add(jobId)
+
+		// Add any dependencies
+		for _, depId := range job.DependsOn {
+			depId = strings.ToLower(depId)
+			depGraph.Add(depId)
+			depGraph.AddEdge(depId, jobId)
+		}
+	}
+	if cycles := depGraph.Cycles(); len(cycles) > 0 {
+		return status.Errorf(codes.FailedPrecondition,
+			"Job dependencies contain one or more cycles: %#v", cycles)
+	}
+
+	// Get our order that we'll create the jobs in. We do a topological
+	// sort so that we get we create dependencies first. This is so that
+	// if someone submits jobs A, B, C that depend on each other in that order
+	// in argumen torder of C, A, B, we can still create, since jobCreate
+	// requires that all dependencies exist.
+	order := depGraph.KahnSort()
+
 	err := s.db.Update(func(dbTxn *bolt.Tx) error {
-		// Go through each job one at a time. If any fail, the transaction
-		// is aborted so the whole thing will fail.
-		for _, job := range jobs {
-			if err := s.jobCreate(dbTxn, txn, job); err != nil {
-				return err
+		// Go through the jobs in DFS-order. This ensures that we create
+		// the jobs that are dependencies first.
+		for _, id := range order {
+			// Create the job. Its okay if it doesn't exist in the jobMap,
+			// that means its just a root node or some other dep already exists.
+			job, ok := jobMap[id.(string)]
+			if ok {
+				if err := s.jobCreate(dbTxn, txn, job); err != nil {
+					return err
+				}
 			}
 		}
 
@@ -213,6 +253,42 @@ func (s *State) JobCreate(jobs ...*pb.Job) error {
 	return err
 }
 
+// Given a Project Ref and a Job Template, this function will generate a slice
+// of QueueJobRequests for every application inside the requested Project
+func (s *State) JobProjectScopedRequest(
+	pRef *pb.Ref_Project,
+	jobTemplate *pb.Job,
+) ([]*pb.QueueJobRequest, error) {
+	var result []*pb.QueueJobRequest
+	project, err := s.ProjectGet(pRef)
+	if err != nil {
+		return nil, err
+	}
+
+	for _, app := range project.Applications {
+		copyJob, err := copystructure.Copy(jobTemplate)
+		if err != nil {
+			return nil, status.Errorf(codes.Internal,
+				"failed to copy job template for project scoped request: %s", err)
+		}
+		tempJob, ok := copyJob.(*pb.Job)
+		if !ok {
+			return nil, status.Errorf(codes.Internal,
+				"failed to convert copied job template into a Job message: %s", err)
+		}
+
+		tempJob.Application = &pb.Ref_Application{
+			Project:     project.Name,
+			Application: app.Name,
+		}
+
+		jobReq := &pb.QueueJobRequest{Job: tempJob}
+		result = append(result, jobReq)
+	}
+
+	return result, nil
+}
+
 // JobList returns the list of jobs.
 func (s *State) JobList() ([]*pb.Job, error) {
 	memTxn := s.inmem.Txn(false)
@@ -246,7 +322,7 @@ func (s *State) JobList() ([]*pb.Job, error) {
 // JobById looks up a job by ID. The returned Job will be a deep copy
 // of the job so it is safe to read/write. If the job can't be found,
 // a nil result with no error is returned.
-func (s *State) JobById(id string, ws memdb.WatchSet) (*Job, error) {
+func (s *State) JobById(id string, ws memdb.WatchSet) (*serverstate.Job, error) {
 	memTxn := s.inmem.Txn(false)
 	defer memTxn.Abort()
 
@@ -287,7 +363,7 @@ func (s *State) JobById(id string, ws memdb.WatchSet) (*Job, error) {
 // (1) jobs are not actually assigned (they remain queued) and (2) this will
 // not block if a job isn't available. If a job isn't available, this will
 // return (nil, nil).
-func (s *State) JobPeekForRunner(ctx context.Context, r *pb.Runner) (*Job, error) {
+func (s *State) JobPeekForRunner(ctx context.Context, r *pb.Runner) (*serverstate.Job, error) {
 	// The false,false here will (1) not block and (2) not assign
 	return s.jobAssignForRunner(ctx, r, false, false)
 }
@@ -301,11 +377,11 @@ func (s *State) JobPeekForRunner(ctx context.Context, r *pb.Runner) (*Job, error
 //
 // If ctx is provided and assignment has to block waiting for new jobs,
 // this will cancel when the context is done.
-func (s *State) JobAssignForRunner(ctx context.Context, r *pb.Runner) (*Job, error) {
+func (s *State) JobAssignForRunner(ctx context.Context, r *pb.Runner) (*serverstate.Job, error) {
 	return s.jobAssignForRunner(ctx, r, true, true)
 }
 
-func (s *State) jobAssignForRunner(ctx context.Context, r *pb.Runner, block, assign bool) (*Job, error) {
+func (s *State) jobAssignForRunner(ctx context.Context, r *pb.Runner, block, assign bool) (*serverstate.Job, error) {
 	var txn *memdb.Txn
 
 RETRY_ASSIGN:
@@ -448,9 +524,10 @@ RETRY_ASSIGN:
 
 		// Update our state and update our on-disk job
 		job.State = pb.Job_WAITING
-		result, err := s.jobReadAndUpdate(job.Id, func(jobpb *pb.Job) error {
+		result, err := s.jobReadAndUpdate(txn, job.Id, func(jobpb *pb.Job) error {
 			jobpb.State = job.State
 			jobpb.AssignTime, err = ptypes.TimestampProto(time.Now())
+			jobpb.AssignedRunner = &pb.Ref_RunnerId{Id: r.Id}
 			if err != nil {
 				// This should never happen since encoding a time now should be safe
 				panic("time encoding failed: " + err.Error())
@@ -463,8 +540,8 @@ RETRY_ASSIGN:
 		}
 
 		// Create our timer to requeue this if it isn't acked
-		job.StateTimer = time.AfterFunc(jobWaitingTimeout, func() {
-			s.log.Info("job ack timer expired", "job", job.Id, "timeout", jobWaitingTimeout)
+		job.StateTimer = time.AfterFunc(serverstate.JobWaitingTimeout, func() {
+			s.log.Info("job ack timer expired", "job", job.Id, "timeout", serverstate.JobWaitingTimeout)
 			s.JobAck(job.Id, false)
 		})
 
@@ -490,7 +567,7 @@ RETRY_ASSIGN:
 // JobAck acknowledges that a job has been accepted or rejected by the runner.
 // If ack is false, then this will move the job back to the queued state
 // and be eligible for assignment.
-func (s *State) JobAck(id string, ack bool) (*Job, error) {
+func (s *State) JobAck(id string, ack bool) (*serverstate.Job, error) {
 	txn := s.inmem.Txn(true)
 	defer txn.Abort()
 
@@ -514,7 +591,7 @@ func (s *State) JobAck(id string, ack bool) (*Job, error) {
 	// We're now modifying this job, so perform a copy
 	job = job.Copy()
 
-	result, err := s.jobReadAndUpdate(job.Id, func(jobpb *pb.Job) error {
+	result, err := s.jobReadAndUpdate(txn, job.Id, func(jobpb *pb.Job) error {
 		if ack {
 			// Set to accepted
 			job.State = pb.Job_RUNNING
@@ -533,6 +610,7 @@ func (s *State) JobAck(id string, ack bool) (*Job, error) {
 			job.State = pb.Job_QUEUED
 			jobpb.State = job.State
 			jobpb.AssignTime = nil
+			jobpb.AssignedRunner = nil
 		}
 
 		return nil
@@ -549,7 +627,7 @@ func (s *State) JobAck(id string, ack bool) (*Job, error) {
 
 	// Create a new timer that we'll use for our heartbeat. After this
 	// timer expires, the job will immediately move to an error state.
-	job.StateTimer = time.AfterFunc(jobHeartbeatTimeout, func() {
+	job.StateTimer = time.AfterFunc(serverstate.JobHeartbeatTimeout, func() {
 		s.log.Info("canceling job due to heartbeat timeout", "job", job.Id)
 		// Force cancel
 		err := s.JobCancel(job.Id, true)
@@ -558,7 +636,7 @@ func (s *State) JobAck(id string, ack bool) (*Job, error) {
 		}
 	})
 
-	s.log.Debug("heartbeat timer set", "job", job.Id, "timeout", jobHeartbeatTimeout)
+	s.log.Debug("heartbeat timer set", "job", job.Id, "timeout", serverstate.JobHeartbeatTimeout)
 
 	// Insert to update
 	if err := txn.Insert(jobTableName, job); err != nil {
@@ -589,6 +667,8 @@ func (s *State) JobUpdateRef(id string, ref *pb.Job_DataSource_Ref) error {
 // The callback is called in the context of a database write lock so it
 // should NOT compute anything and should be fast. The callback can return
 // an error to abort the transaction.
+//
+// Job states should NOT be modified using this, only metadata.
 func (s *State) JobUpdate(id string, cb func(jobpb *pb.Job) error) error {
 	txn := s.inmem.Txn(true)
 	defer txn.Abort()
@@ -603,7 +683,7 @@ func (s *State) JobUpdate(id string, cb func(jobpb *pb.Job) error) error {
 	}
 	job := raw.(*jobIndex)
 
-	_, err = s.jobReadAndUpdate(job.Id, func(jobpb *pb.Job) error {
+	_, err = s.jobReadAndUpdate(txn, job.Id, func(jobpb *pb.Job) error {
 		return cb(jobpb)
 	})
 	if err != nil {
@@ -651,7 +731,7 @@ func (s *State) JobComplete(id string, result *pb.Job_Result, cerr error) error
 	// We're now modifying this job, so perform a copy
 	job = job.Copy()
 
-	_, err = s.jobReadAndUpdate(job.Id, func(jobpb *pb.Job) error {
+	_, err = s.jobReadAndUpdate(txn, job.Id, func(jobpb *pb.Job) error {
 		// Set to complete, assume success for now
 		job.State = pb.Job_SUCCESS
 		jobpb.State = job.State
@@ -750,7 +830,7 @@ func (s *State) jobCancel(txn *memdb.Txn, job *jobIndex, force bool) error {
 	}
 
 	// Persist the on-disk data
-	_, err := s.jobReadAndUpdate(job.Id, func(jobpb *pb.Job) error {
+	_, err := s.jobReadAndUpdate(txn, job.Id, func(jobpb *pb.Job) error {
 		var err error
 		jobpb.State = job.State
 		jobpb.CancelTime, err = ptypes.TimestampProto(time.Now())
@@ -823,7 +903,7 @@ func (s *State) jobHeartbeat(txn *memdb.Txn, id string) error {
 	}
 
 	// Reset the timer
-	job.StateTimer.Reset(jobHeartbeatTimeout)
+	job.StateTimer.Reset(serverstate.JobHeartbeatTimeout)
 
 	return nil
 }
@@ -965,6 +1045,7 @@ func (s *State) jobIndexSet(txn *memdb.Txn, id []byte, jobpb *pb.Job) (*jobIndex
 	rec := &jobIndex{
 		Id:          jobpb.Id,
 		SingletonId: jobpb.SingletonId,
+		DependsOn:   jobpb.DependsOn,
 		State:       jobpb.State,
 		Application: jobpb.Application,
 		Workspace:   jobpb.Workspace,
@@ -1006,7 +1087,7 @@ func (s *State) jobIndexSet(txn *memdb.Txn, id []byte, jobpb *pb.Job) (*jobIndex
 	// We reset the nack timer so it gives runners time to reconnect.
 	if rec.State == pb.Job_WAITING {
 		// Create our timer to requeue this if it isn't acked
-		rec.StateTimer = time.AfterFunc(jobWaitingTimeout, func() {
+		rec.StateTimer = time.AfterFunc(serverstate.JobWaitingTimeout, func() {
 			s.JobAck(rec.Id, false)
 		})
 	}
@@ -1014,7 +1095,7 @@ func (s *State) jobIndexSet(txn *memdb.Txn, id []byte, jobpb *pb.Job) (*jobIndex
 	// If this job is running, we need to restart a heartbeat timeout.
 	// This should only happen on reinit. This is tested.
 	if rec.State == pb.Job_RUNNING {
-		rec.StateTimer = time.AfterFunc(jobHeartbeatTimeout, func() {
+		rec.StateTimer = time.AfterFunc(serverstate.JobHeartbeatTimeout, func() {
 			// Force cancel
 			s.JobCancel(rec.Id, true)
 		})
@@ -1095,6 +1176,33 @@ func (s *State) jobCreate(dbTxn *bolt.Tx, memTxn *memdb.Txn, jobpb *pb.Job) erro
 		}
 	}
 
+	// If we have dependencies, they all must exist.
+	dependsMap := map[string]struct{}{}
+	if len(jobpb.DependsOn) > 0 {
+		// Let's remove any duplicates
+		jobpb.DependsOn = uniqueStr(jobpb.DependsOn)
+
+		// Go through and ensure that each exists.
+		for _, id := range jobpb.DependsOn {
+			dependsMap[id] = struct{}{}
+
+			_, err := s.jobById(dbTxn, id)
+			if err != nil {
+				return err
+			}
+		}
+	}
+
+	// Allowed failures must be in the DependsOn list
+	for _, id := range jobpb.DependsOnAllowFailure {
+		if _, ok := dependsMap[id]; !ok {
+			return status.Errorf(codes.FailedPrecondition,
+				"job %q in depends_on_allow_failure but not in depends_on",
+				id,
+			)
+		}
+	}
+
 	// Insert into bolt
 	if err := dbPut(dbTxn.Bucket(jobBucket), id, jobpb); err != nil {
 		return err
@@ -1135,7 +1243,8 @@ func (s *State) jobById(dbTxn *bolt.Tx, id string) (*pb.Job, error) {
 	return &result, dbGet(b, []byte(id), &result)
 }
 
-func (s *State) jobReadAndUpdate(id string, f func(*pb.Job) error) (*pb.Job, error) {
+func (s *State) jobReadAndUpdate(
+	memTxn *memdb.Txn, id string, f func(*pb.Job) error) (*pb.Job, error) {
 	var result *pb.Job
 	var err error
 	return result, s.db.Update(func(dbTxn *bolt.Tx) error {
@@ -1149,11 +1258,103 @@ func (s *State) jobReadAndUpdate(id string, f func(*pb.Job) error) (*pb.Job, err
 			return err
 		}
 
+		// Cascade our state if we have to. We do this within the database
+		// transaction so that error updates the full dependent chain or
+		// nothing.
+		if err := s.jobCascadeDependentState(memTxn, dbTxn, result); err != nil {
+			return err
+		}
+
 		// Commit
 		return dbPut(dbTxn.Bucket(jobBucket), []byte(id), result)
 	})
 }
 
+// jobCascadeDependentState cascades certain state changes to all dependent
+// jobs. For example, if a job transitions to an error state, then all
+// dependents must also error.
+func (s *State) jobCascadeDependentState(
+	memTxn *memdb.Txn,
+	dbTxn *bolt.Tx,
+	parent *pb.Job,
+) error {
+	// If the state isn't error, we don't cascade anything.
+	if parent.State != pb.Job_ERROR {
+		return nil
+	}
+
+	// Look for any dependents
+	iter, err := memTxn.Get(jobTableName, jobDependsOnIndexName, parent.Id)
+	if err != nil {
+		return err
+	}
+
+	for {
+		next := iter.Next()
+		if next == nil {
+			break
+		}
+		idx := next.(*jobIndex)
+
+		// The state SHOULD be queued if the job is still waiting on us.
+		// We only handle this scenario. If it isn't queued, we just ignore
+		// it because we're in a state we don't understand.
+		if idx.State != pb.Job_QUEUED {
+			continue
+		}
+
+		// Read this dependent job from disk so we can update the proto struct.
+		job, err := s.jobById(dbTxn, idx.Id)
+		if status.Code(err) == codes.NotFound {
+			continue
+		}
+		if err != nil {
+			return err
+		}
+
+		// If this dependency is allowed to fail, do not cascade.
+		failAllowed := false
+		for _, id := range job.DependsOnAllowFailure {
+			if strings.EqualFold(id, parent.Id) {
+				failAllowed = true
+				break
+			}
+		}
+		if failAllowed {
+			continue
+		}
+
+		// Cascade the error state
+		job.State = pb.Job_ERROR
+		job.Error = status.New(codes.Canceled, fmt.Sprintf(
+			"Job dependency %q errored: %s",
+			parent.Id,
+			parent.Error.Message,
+		)).Proto()
+		job.CancelTime = parent.CancelTime
+
+		// Write to disk
+		if err := dbPut(dbTxn.Bucket(jobBucket), []byte(job.Id), job); err != nil {
+			return err
+		}
+
+		// Write to memory index. Error state is terminal so we also call End.
+		idx = idx.Copy()
+		idx.State = job.State
+		idx.End()
+		if err := memTxn.Insert(jobTableName, idx); err != nil {
+			return err
+		}
+
+		// Cascade further if necessary
+		if err := s.jobCascadeDependentState(memTxn, dbTxn, job); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 // jobCandidateById returns the most promising candidate job to assign
 // that is targeting a specific runner by ID.
 func (s *State) jobCandidateById(
@@ -1240,8 +1441,8 @@ func (idx *jobIndex) Copy() *jobIndex {
 }
 
 // Job returns the Job for an index.
-func (idx *jobIndex) Job(jobpb *pb.Job) *Job {
-	return &Job{
+func (idx *jobIndex) Job(jobpb *pb.Job) *serverstate.Job {
+	return &serverstate.Job{
 		Job:          jobpb,
 		OutputBuffer: idx.OutputBuffer,
 	}
@@ -1254,3 +1455,16 @@ func (idx *jobIndex) End() {
 		idx.StateTimer = nil
 	}
 }
+
+// uniqueStr is a little helper to ensure a string slice only has unique values.
+func uniqueStr(s []string) []string {
+	keys := map[string]struct{}{}
+	result := make([]string, 0, len(s))
+	for _, value := range s {
+		if _, ok := keys[value]; !ok {
+			keys[value] = struct{}{}
+			result = append(result, value)
+		}
+	}
+	return result
+}
