@@ -1861,6 +1861,7 @@ const odrRolePolicy = `{
         "ec2:AuthorizeSecurityGroupIngress",
         "ec2:CreateSecurityGroup",
         "ec2:DescribeSecurityGroups",
+        "ec2:DeleteSecurityGroup",
         "ec2:DescribeSubnets",
         "ecr:BatchGetImage",
         "ecr:CompleteLayerUpload",
@@ -1886,6 +1887,7 @@ const odrRolePolicy = `{
         "ecs:ListTasks",
         "ecs:DescribeTasks",
         "ecs:RegisterTaskDefinition",
+        "ecs:DeregisterTaskDefinition",
         "ecs:RunTask",
         "elasticloadbalancing:CreateListener",
         "elasticloadbalancing:CreateLoadBalancer",
@@ -2498,6 +2500,6 @@ func (i *ECSInstaller) OnDemandRunnerConfig() *pb.OnDemandRunnerConfig {
 		PluginType:   "aws-ecs",
 		Default:      true,
 		PluginConfig: cfgJson,
-		ConfigFormat: pb.Project_JSON,
+		ConfigFormat: pb.Hcl_JSON,
 	}
 }
