@@ -1,11 +1,10 @@
-import { inject as service } from '@ember/service';
 import Component from '@glimmer/component';
-import SessionService from 'waypoint/services/session';
-
+import SessionService from 'ember-simple-auth/services/session';
+import { inject as service } from '@ember/service';
 export default class Header extends Component {
   @service session!: SessionService;
 
   get canLogout(): boolean {
-    return this.session.authConfigured;
+    return this.session.isAuthenticated;
   }
 }
