@@ -4,15 +4,15 @@ import { action } from '@ember/object';
 import { tracked } from '@glimmer/tracking';
 import ApiService from 'waypoint/services/api';
 import { Project, UpsertProjectRequest } from 'waypoint-pb';
-import FlashMessagesService from 'waypoint/services/flash-messages';
+import FlashMessagesService from 'waypoint/services/pds-flash-messages';
 export default class WorkspaceProjectsNew extends Controller {
   @service api!: ApiService;
-  @service flashMessages!: FlashMessagesService;
+  @service('pdsFlashMessages') flashMessages!: FlashMessagesService;
 
   @tracked createGit = false;
 
   @action
-  async saveProject(e: Event) {
+  async saveProject(e: Event): Promise<void> {
     e.preventDefault();
     let project = this.model;
     let ref = new Project();
